Package: dsBaseClient
Title: 'DataSHIELD' Client Side Base Functions
Version: 6.3.5
Description: Base 'DataSHIELD' functions for the client side. 'DataSHIELD' is a software package which allows
    you to do non-disclosive federated analysis on sensitive data. 'DataSHIELD' analytic functions have
    been designed to only share non disclosive summary statistics, with built in automated output
    checking based on statistical disclosure control. With data sites setting the threshold values for
    the automated output checks. For more details, see citation('dsBaseClient').
Authors@R: c(person(given = "Paul",
                    family = "Burton",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0001-5799-9634")),
             person(given = "Rebecca",
                    family = "Wilson",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0003-2294-593X")),
             person(given = "Olly",
                    family = "Butters",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0003-0354-8461")),
             person(given = "Patricia",
                    family = "Ryser-Welch",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0002-0070-0264")),
             person(given = "Alex",
                    family = "Westerberg",
                    role = c("aut")),
             person(given = "Leire",
                    family = "Abarrategui",
                    role = c("aut")),
             person(given = "Roberto",
                    family = "Villegas-Diaz",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0001-5036-8661")),
             person(given = "Demetris",
                    family = "Avraam",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0001-8908-2441")),
             person(given = "Yannick",
                    family = "Marcon",
                    role = c("aut"),
                    email = "yannick.marcon@obiba.org",
                    comment = c(ORCID = "0000-0003-0138-2023")),
             person(given = "Tom",
                    family = "Bishop",
                    role = c("aut")),
             person(given = "Amadou",
                    family = "Gaye",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0002-1180-2792")),
             person(given = "Xavier",
                    family = "Escribà-Montagut",
                    role = c("aut"),
                    comment = c(ORCID = "0000-0003-2888-8948")),
             person(given = "Stuart",
                    family = "Wheater",
                    role = c("aut", "cre"),
                    email = "stuart.wheater@arjuna.com",
                    comment = c(ORCID = "0009-0003-2419-1964")))
License: GPL-3
Depends: R (>= 4.0.0), DSI (>= 1.7.1)
Imports: fields, metafor, meta, ggplot2, gridExtra, data.table,
        methods, dplyr
Suggests: lme4, httr, spelling, tibble, testthat, e1071, DescTools,
        DSOpal, DSMolgenisArmadillo, DSLite
RoxygenNote: 7.3.3
Encoding: UTF-8
Language: en-GB
NeedsCompilation: no
Packaged: 2025-12-21 16:23:22 UTC; swheater
Author: Paul Burton [aut] (ORCID: <https://orcid.org/0000-0001-5799-9634>),
  Rebecca Wilson [aut] (ORCID: <https://orcid.org/0000-0003-2294-593X>),
  Olly Butters [aut] (ORCID: <https://orcid.org/0000-0003-0354-8461>),
  Patricia Ryser-Welch [aut] (ORCID:
    <https://orcid.org/0000-0002-0070-0264>),
  Alex Westerberg [aut],
  Leire Abarrategui [aut],
  Roberto Villegas-Diaz [aut] (ORCID:
    <https://orcid.org/0000-0001-5036-8661>),
  Demetris Avraam [aut] (ORCID: <https://orcid.org/0000-0001-8908-2441>),
  Yannick Marcon [aut] (ORCID: <https://orcid.org/0000-0003-0138-2023>),
  Tom Bishop [aut],
  Amadou Gaye [aut] (ORCID: <https://orcid.org/0000-0002-1180-2792>),
  Xavier Escribà-Montagut [aut] (ORCID:
    <https://orcid.org/0000-0003-2888-8948>),
  Stuart Wheater [aut, cre] (ORCID:
    <https://orcid.org/0009-0003-2419-1964>)
Maintainer: Stuart Wheater <stuart.wheater@arjuna.com>
Repository: CRAN
Date/Publication: 2026-01-07 08:20:07 UTC
Built: R 4.6.0; ; 2026-04-29 15:50:51 UTC; unix
