# Generated by roxygen2: do not edit by hand

export(ds.Boole)
export(ds.abs)
export(ds.asCharacter)
export(ds.asDataMatrix)
export(ds.asFactor)
export(ds.asFactorSimple)
export(ds.asInteger)
export(ds.asList)
export(ds.asLogical)
export(ds.asMatrix)
export(ds.asNumeric)
export(ds.assign)
export(ds.auc)
export(ds.boxPlot)
export(ds.bp_standards)
export(ds.c)
export(ds.cbind)
export(ds.changeRefGroup)
export(ds.class)
export(ds.colnames)
export(ds.completeCases)
export(ds.contourPlot)
export(ds.cor)
export(ds.corTest)
export(ds.cov)
export(ds.dataFrame)
export(ds.dataFrameFill)
export(ds.dataFrameSort)
export(ds.dataFrameSubset)
export(ds.densityGrid)
export(ds.dim)
export(ds.dmtC2S)
export(ds.elspline)
export(ds.exists)
export(ds.exp)
export(ds.forestplot)
export(ds.gamlss)
export(ds.getWGSR)
export(ds.glm)
export(ds.glmPredict)
export(ds.glmSLMA)
export(ds.glmSummary)
export(ds.glmerSLMA)
export(ds.heatmapPlot)
export(ds.hetcor)
export(ds.histogram)
export(ds.igb_standards)
export(ds.isNA)
export(ds.isValid)
export(ds.kurtosis)
export(ds.length)
export(ds.levels)
export(ds.lexis)
export(ds.list)
export(ds.listClientsideFunctions)
export(ds.listDisclosureSettings)
export(ds.listOpals)
export(ds.listServersideFunctions)
export(ds.lmerSLMA)
export(ds.log)
export(ds.look)
export(ds.ls)
export(ds.lspline)
export(ds.make)
export(ds.matrix)
export(ds.matrixDet)
export(ds.matrixDet.report)
export(ds.matrixDiag)
export(ds.matrixDimnames)
export(ds.matrixInvert)
export(ds.matrixMult)
export(ds.matrixTranspose)
export(ds.mdPattern)
export(ds.mean)
export(ds.meanByClass)
export(ds.meanSdGp)
export(ds.merge)
export(ds.message)
export(ds.metadata)
export(ds.mice)
export(ds.names)
export(ds.ns)
export(ds.numNA)
export(ds.qlspline)
export(ds.quantileMean)
export(ds.rBinom)
export(ds.rNorm)
export(ds.rPois)
export(ds.rUnif)
export(ds.ranksSecure)
export(ds.rbind)
export(ds.reShape)
export(ds.recodeLevels)
export(ds.recodeValues)
export(ds.rep)
export(ds.replaceNA)
export(ds.rm)
export(ds.rowColCalc)
export(ds.sample)
export(ds.scatterPlot)
export(ds.seq)
export(ds.setDefaultOpals)
export(ds.setSeed)
export(ds.skewness)
export(ds.sqrt)
export(ds.subset)
export(ds.subsetByClass)
export(ds.summary)
export(ds.table)
export(ds.table1D)
export(ds.table2D)
export(ds.tapply)
export(ds.tapply.assign)
export(ds.testObjExists)
export(ds.unList)
export(ds.unique)
export(ds.var)
export(ds.vectorCalc)
export(subsetHelper)
import(DSI)
import(data.table)
importFrom(stats,as.formula)
importFrom(stats,na.omit)
importFrom(stats,ts)
importFrom(stats,weighted.mean)
