\name{datashield.heatmap.plot}
\alias{datashield.heatmap.plot}
\title{Plots a heatmap}
\usage{
  datashield.heatmap.plot(opals, xvect, yvect)
}
\arguments{
  \item{xvect}{a numerical vector}

  \item{yvect}{a numerical vector}
}
\value{
  a heatmap plot.
}
\description{
  Generates a heatmap plot
}
\author{
  Isaeva, J.
}

