\name{datashield.contour.plot}
\alias{datashield.contour.plot}
\title{Creates a contour plot}
\usage{
  datashield.contour.plot(opals, xvect, yvect)
}
\arguments{
  \item{opals}{character strings that represent the URL of
  the servers where the study datasets are stored.}

  \item{xvect}{a numerical vector}

  \item{yvect}{a numerical vector}
}
\value{
  a contour plot.
}
\description{
  Generates a contour plot of the given data values.
}
\author{
  Burton, P.
}

