\name{datashield.table.2d}
\alias{datashield.table.2d}
\title{Creates a 2D table}
\usage{
  datashield.table.2d(opals, a, b)
}
\arguments{
  \item{opals}{character strings that represent the URL of
  the servers where the study datasets are stored.}

  \item{a}{a numerical vector}

  \item{a}{a numerical vector}
}
\value{
  a 2D table
}
\description{
  Generates a combine 2D table across all the datasets
}
\author{
  Burton, P.
}

