\name{table1dhelper3}
\alias{table1dhelper3}
\title{Generates percents from counts returned by the function \code{table1d.ds}}
\usage{
table1dhelper3(a.boolean, a.matrix, a.list)
}
\arguments{
  \item{a.boolean}{a boolean that indicates whether or not
  all the studies are invalid}

  \item{a.matrix}{a matrix containing study specific and
  overall (combined) tables of counts based ONLY on data
  from studies where all table categories are VALID - this
  matrix is generated by the function
  \code{table1dhelper2}}

  \item{a.list}{a list of primary outputs from ALL studies
  ("STUDY.NAME","IS.STUDY.DATA.VALID?","TABLE.MASKED.COUNTS")}
}
\value{
a list that contains summary tables with columns and rows
percents
}
\description{
this is an INTERNAL function required by the helper
function \code{table1dhelper4} functions. It generates
percents from the count tables.
}
\details{


the function is not 'exported' and hence not visible to
user and is only called by \code{ds.table1d}
}
\author{
Burton, P.; Gaye, A.
}

